// NeoPixel Ring simple sketch (c) 2013 Shae Erisson
// released under the GPLv3 license to match the rest of the AdaFruit NeoPixel library
//
// Seb : client arduino pour reception commandes de l'interface
// de parametrage du ring via ChromeApp Cooler Master
//
// Revision : 28.02.2016 - Mémorisation de l'effets dans lEEPROM de l'arduino (attention 512 bytes seulement)
// Création de 4 effets paramètrable en couleur et en vitesse
//
// Paramétrage vitesse port serie : 38400 Bauds (Au dela ne fonctionne plus...)
// Ring NeoPixel Ring de 12 led 
// Remarques : Les effects sont codés de manière à faire des traitement unitaires non blocant permettant
// de prendre en compte rapidement les modifications envoyé par l'utilisateur (changement de vitesse, couleurs, etc...)
// Ne pas utiliser la fonction DELAY qui est blocante ! 
// activeLedStrip 1 = le ring / 2 = la bande de led dans le case pour éclairage de la carte.
// 13.03.16 - Quick & dirty add gestion d'une seconde bande de led
// 29.06.16 - Transmission à l'interface du Nb de led à gérer
// debug de l'animation back an Forward...


#include <EEPROM.h>
#include <Adafruit_NeoPixel.h>
#ifdef __AVR__
  #include <avr/power.h>
#endif

// Which pin on the Arduino is connected to the NeoPixels?
#define PIN            10
#define PINSTRIP       9

// How many NeoPixels are attached to the Arduino?
#define NUMPIXELS       16
#define NUMPIXELSSTRIP  16

#define STOP  0
#define EFFE1 1
#define EFFE2 2
#define EFFE3 3
#define EFFE4 4

#define DEFAULT_BRIGHTNESS 200


boolean DEBUG=false; // Active l'affichage des messages de debug
int IDAPPLI=38; // Identifiant unique de l'application, stocké dans leeprom pour valider format ecriture/lecture lors des evolutions...

// Timer to delay animation...
unsigned long previousMillis = 0;
unsigned long previousMillisBlowEffect =0;
unsigned long previousMillisBackAndForward =0;

unsigned long currentMillis = millis();

boolean led[NUMPIXELS];
boolean ledstrip[NUMPIXELSSTRIP];

// contient le no de la rampe de led sur laquelle vont s'appliquer les instructions à venir
int configLedStrip = 1; // par defaut le ring

int nbpassage=0;
String inputString = "";         // a string to hold incoming data
boolean stringComplete = false;  // whether the string is complete

uint32_t userRingColor; // The color sent by the user apply to all effects.
uint32_t userStripColor; // The color sent by the user apply to all effects.

uint32_t ledOff; // Color for Led OFF
int speedEffect; // The speed for effects 

// the no of the active effect on the ring and Strip by default all set set on
int runEffect, runEffectStrip; 

int cptin=0; // comptage du nb de caractères reçu
int dirEffectNo3=0;

// Pour Effet no 3 :
boolean looptab[NUMPIXELS];
boolean looptabstrip[NUMPIXELSSTRIP];

int dirEffect=0;

// Pour l'Effet no 4 :
int brightness=128;
int dirBrightness=+1;

// variable temporaire contenant l'effet sélectionné
int selEffect;

// When we setup the NeoPixel library, we tell it how many pixels, and which pin to use to send signals.
// Note that for older NeoPixel strips you might need to change the third parameter--see the strandtest
// example for more information on possible values.
Adafruit_NeoPixel pixels = Adafruit_NeoPixel(NUMPIXELS, PIN, NEO_GRB + NEO_KHZ800);
Adafruit_NeoPixel pixelsstrip = Adafruit_NeoPixel(NUMPIXELSSTRIP, PINSTRIP, NEO_GRB + NEO_KHZ800);

// Relit les principaux paramètres de l'effet dans l'eeprom
void loadEffect() {
  int eeAddress = 0;   //Location we want the data to be put.
  int controlApplicationId=0;
  
  // Lecture de la premiere adresse...
  EEPROM.get(eeAddress, controlApplicationId);
  eeAddress += sizeof(int);
    
  // S'il n'y à pas déja eu au moins une sauvegarde on ne lit pas les infos présentes en mémoire...
   
  if (controlApplicationId == IDAPPLI) {
    EEPROM.get(eeAddress,runEffect);
    eeAddress += sizeof(int);

    EEPROM.get(eeAddress,runEffectStrip);
    eeAddress += sizeof(int);
    
    // lit la couleur du ring
    EEPROM.get(eeAddress,userRingColor);
    eeAddress += sizeof(uint32_t );

    EEPROM.get(eeAddress,userStripColor);
    eeAddress += sizeof(uint32_t );

    // lit la vitesse de l'effet
    EEPROM.get(eeAddress,speedEffect);
    eeAddress += sizeof(int);
  
    // lit l'état de chaque LED 
   for(int i=0;i<NUMPIXELS;i++){
      EEPROM.get(eeAddress,led[i]);
      eeAddress += sizeof(boolean);
   }

  // lit le tableau pour l'animation
   for(int i=0;i<NUMPIXELS;i++){
      EEPROM.get(eeAddress,looptab[i]);
      eeAddress += sizeof(boolean);
   }

    // ---------- Renvoie les données à l'interface pour paramétrage des valeurs à l'écran -------
    // Serial.println("Relecture OK");
    // Renvoie à l'interface la valeur de la vitesse de l'effet
    // Serial.print("SPED"+String(speedEffect)+"\n");
    //Serial.flush();
     
    // Renvoie la couleur du ring
    // Calcul les composantes R / V / B et les mets en Hexa à partir  de la couleur de la led stocké format uint32..
    // uint32_t Adafruit_NeoPixel::Color(uint8_t r, uint8_t g, uint8_t b) { return ((uint32_t)r << 16) | ((uint32_t)g <<  8) | b;  }
    String b = String((uint8_t)(userRingColor & (uint32_t)255),HEX);
    if (b.length()==1) b="0"+b;
    
    String v = String((uint8_t)(userRingColor >>8 & (uint32_t)255),HEX);
    if (v.length()==1) v="0"+v;
    
    String r = String((uint8_t)(userRingColor >>16 & (uint32_t)255),HEX);
    if (r.length()==1) r="0"+r;
    
    Serial.print("RVB#"+r+v+b+"\n");
    
    // renvoie le no de l'effet sur le ring
    Serial.print("EFFE"+String(runEffect)+"\n");

   // --- Envoie la config des led (eteind toutes celles qui doivent l'êtres... ---
   for(int i=0;i<NUMPIXELS;i++){
    if (led[i]==false) Serial.print("LEDF"+String(i)+"\n");
   }

        
  } else {
    Serial.println("Il n'y a pas encore eu de sauvegarde, effet par defaut"); 

    // Couleur par défaut : Le jaune Quai-Lab :-) 
    runEffect=EFFE2;
    userRingColor = pixels.Color(250,230,48);

    runEffectStrip=EFFE3;    
    userStripColor = pixelsstrip.Color(250,230,48);
    
    // Vitesse des effets en ms
    speedEffect = 30;
  
    // Toutes les LEDs allumées par défaut
    for(int i=0;i<NUMPIXELS;i++){led[i]=true;}
       
  }
  
    // renvoie le nombre de LED à gérer à l'interface Graphique
    // création dynamique sur l'interface des leds...
    Serial.print("NBLED"+String(NUMPIXELS)+"\n");
  
}



// Sauve les principaux paramètres de l'effet dans l'eeprom
void saveEffect() {
  int eeAddress = 0;   
  
  EEPROM.put(eeAddress,IDAPPLI);
  eeAddress += sizeof(int); // la premiere données est pour vérifier que l'on est bien sur notre application (risky but...)
 
  // sauve le no de l'effet ring
  EEPROM.put(eeAddress,runEffect);
  eeAddress += sizeof(int);

  // sauve le no de l'effet strip
  EEPROM.put(eeAddress,runEffectStrip);
  eeAddress += sizeof(int);

  // sauve la couleur du ring
  EEPROM.put(eeAddress,userRingColor);
  eeAddress += sizeof(uint32_t );

  // sauve la couleur du strip
  EEPROM.put(eeAddress,userStripColor);
  eeAddress += sizeof(uint32_t );

  // Sauve la vitesse de l'effet
  EEPROM.put(eeAddress,speedEffect);
  eeAddress += sizeof(int);

  // sauve l'état de chaque LED 
 for(int i=0;i<NUMPIXELS;i++){
    EEPROM.put(eeAddress,led[i]);
   // Serial.print("LED no");Serial.print(i);Serial.println(led[i]);
    eeAddress += sizeof(boolean);
 }

  // sauve le tableau pour l'animation
  // Attention cas spéciale pour l'effet no 2, Il faut réinitialiser le tableau avant la sauvegarde
  if (runEffect==EFFE2) init_loopingEffect(1);
  if (runEffectStrip==EFFE2) init_loopingEffect(2);

  // Sauvegarde le tableau d'animation pour l'effet
   for(int i=0;i<NUMPIXELS;i++){
      EEPROM.put(eeAddress,looptab[i]);
      eeAddress += sizeof(boolean);
   }
  
  debugMsg("Sauvegarde OK");
}


void setup() {
  // initialize serial:
  Serial.begin(38400);
  // reserve 200 bytes for the inputString:
  inputString.reserve(200);

  // This is for Trinket 5V 16MHz, you can remove these three lines if you are not using a Trinket
  #if defined (__AVR_ATtiny85__)
    if (F_CPU == 16000000) clock_prescale_set(clock_div_1);
  #endif
  // End of trinket special code

  pixels.begin(); // This initializes the NeoPixel library.
  pixelsstrip.begin(); // The strip led

  pixels.setBrightness(DEFAULT_BRIGHTNESS); 
  pixelsstrip.setBrightness(DEFAULT_BRIGHTNESS); 

  ledOff=pixels.Color(0,0,0);

  // pas de gestion led allumee/eteinte à lunité pour le strip.
  for(int i=0;i<NUMPIXELSSTRIP;i++){ledstrip[i]=true;}
    
  // Recharge les paramètres en mémoire de l'effet sauvegardé, sinon configure un effet par défaut.
   loadEffect();
}


void loop() {

// Gere la rampe de led 1 puis ensuite la 2
for (int j=1;j<3;j++) {
  // Check Which effect need to be set
  if (j==1) selEffect=runEffect;
  // if (j==2) selEffect=runEffectStrip;
  
  switch (selEffect) {
    case STOP:
      stopEffect(j);
      break;
    case EFFE1:
      allLedset(j);
      break;
    case EFFE2:
      loopingEffect(j);
      break;
    case EFFE3:
      backAndForwardEffect(j);
      break;
    case EFFE4:
      blowingEffect(j);
      break;
    default: 
      // if nothing else matches, do the default
      // default is optional
    break;
  }
}
  
  // print the string when a newline arrives:
  if (stringComplete) {
    debugMsg(inputString);

    // chaineReception.trim(); // enlève les espaces
    analyseChaine(inputString); // appelle la fonction d'analyse de la chaine en réception
    
    // clear the string:
    inputString = "";
    stringComplete = false;
  }
}

/*
  SerialEvent occurs whenever a new data comes in the
 hardware serial RX.  This routine is run between each
 time loop() runs, so using delay inside loop can delay
 response.  Multiple bytes of data may be available.
 */
void serialEvent() {
  while (Serial.available()) {
    // get the new byte:
    char inChar = (char)Serial.read();

    // add it to the inputString:
    inputString += inChar;
    cptin++;
   
    // if the incoming character is a newline, set a flag
    // so the main loop can do something about it:
    if (inChar == '\n' || cptin==10) {
      stringComplete = true;
      cptin=0;
      debugMsg(inputString);
    }
  }
}

//
//  Analyse les instructions recus via le serie
//
void analyseChaine(String chaineRecue) { // fonction d'analyse de la chaine recue

      int valeur=0; // variable utile
      String chaineTest; // objet STring pour analyse chaine recue

      // convertie les lettres en majuscules, pour rendre les commandes case insensitives...
      chaineRecue.toUpperCase();

      if (chaineRecue.startsWith("HELP"))  showInstructions();

      // Selectionne la rampe de led sur laquelle vont s'appliquer les effets
      if (chaineRecue.startsWith("RING"))   configLedStrip=1;
      if (chaineRecue.startsWith("STRIP"))  configLedStrip=2;
          
      if (chaineRecue.startsWith("SAVE"))  saveEffect();

      if (chaineRecue.startsWith("LOAD")) loadEffect();

      if (chaineRecue.startsWith("DEBUGON")) DEBUG=true;
      if (chaineRecue.startsWith("DEBUGOFF")) DEBUG=false;

      if (chaineRecue.startsWith("SPED")) { 
          // recupere la valeur situé après EFFE
          String speedS=chaineRecue.substring(4);
        
          // recupere la valeur envoyé et l'affecte à la variable Globale
          speedEffect= speedS.toInt();
      }


      if (chaineRecue.startsWith("EFFE")) { // si la chaine débute par EFFE...
          // recupere la valeur situé après EFFE
          String noEffet=chaineRecue.substring(4);
          
          // recupere la valeur envoyé et l'affecte à la variable Globale
         if (configLedStrip==1) runEffect= noEffet.toInt();
         if (configLedStrip==2) runEffectStrip= noEffet.toInt();
         debugMsg("Recu effet no : ");debugMsg(String(runEffect));debugMsg(" Rampe de led ");debugMsg(String(configLedStrip));          
          
          // EFFET 3 : Initialisation du tableau de gestion des led en fonction de l'effet
          if (runEffect==EFFE3) resetLoopTab(1);
          if (runEffectStrip==EFFE3) resetLoopTab(2);          

          
          // EFFET 2 : construit le tableau avec N led allumées qui tourneront 
          if (runEffect==EFFE2 ) init_loopingEffect(1);
          if (runEffectStrip==EFFE2) init_loopingEffect(2);
                    
          // Lancer une mise à Zero des leds pour avoir un effets de transition entre 2 animations... ?
          // reconfigure une valeure pour l'intensité des LED
          pixels.setBrightness(DEFAULT_BRIGHTNESS); 
      }

      // Alumage / Extinction d'une LED : uniquement pour la Rampe no 1 !!!!!
      // Les leds de la rampe no 2 sont toujours à TRUE defini à l'initialisation
      if (chaineRecue.startsWith("LEDF")) { 
          // recupere la valeur situé après LEDF
          String noLed=chaineRecue.substring(4);
          debugMsg(noLed);
          
          // Affecte False à la led dont ont à recu le no
          led[noLed.toInt()]=false;
          debugMsg(String(noLed.toInt()));
      }  

      if (chaineRecue.startsWith("LEDT")) { 
          // recupere la valeur situé après LEDT
          String noLed=chaineRecue.substring(4);
          
          // Affecte False à la led dont ont à recu le no
          led[noLed.toInt()]=true;
      }  
      // ------------------------------------------------------
      
      // --- Eteind les leds (sans changer le tableau on/off ---
      if (chaineRecue.startsWith("STOP")) { 
          if (configLedStrip==1) runEffect= STOP;
          if (configLedStrip==2) runEffectStrip= STOP;
      }

      
      if (chaineRecue.startsWith("RVB#")) { // si la chaine débute par RVB
          String tmp;
          tmp = String();
          int r,v,b;
          
          // recupère le code hexa de la couleur à afficher
          // tmp = String(chaineRecue[3])+String(chaineRecue[4]);
          
          // Les codes couleur RVB
          r=hextodec(String(chaineRecue[4])+String(chaineRecue[5]));
          v=hextodec(String(chaineRecue[6])+String(chaineRecue[7]));
          b=hextodec(String(chaineRecue[8])+String(chaineRecue[9]));;
                   
          if (configLedStrip==1) userRingColor=pixels.Color(r,v,b);
          if (configLedStrip==2) userStripColor=pixelsstrip.Color(r,v,b);
            
          debugMsg("Reception RVB color OK");
      }

      if (chaineRecue.startsWith("LEDR-0")) { // si la chaine débute par la chaine servoOFF
          pixels.setPixelColor(1, pixels.Color(0,0,0)); // Moderately bright green color.
          pixels.show();
          
          debugMsg("Led Rouge Eteinte");
      }
} // fin fonction analyse chaine

// Recois un caractere hexa sur 2 octets et renvoie sa valeur décimal 
int hextodec(String hexaval) {
         int colorval=0;
         debugMsg("In hextodec : ");
         debugMsg(hexaval);
         
          if (hexaval[0]>=48 && hexaval[0]<=57) colorval=colorval+(hexaval[0]-48)*16;
          if (hexaval[0]>=65 && hexaval[0]<=70) colorval=colorval+(hexaval[0]-65+10)*16;

          if (hexaval[1]>=48 && hexaval[1]<=57) colorval=colorval+(hexaval[1]-48);
          if (hexaval[1]>=65 && hexaval[1]<=70) colorval=colorval+(hexaval[1]-65+10);

          debugMsg(String(colorval));
          return colorval;
 }  

// -----------------------------------------------------------------------
// Effet no 1 : Toutes les leds allumées
// IN : Met la couleur de led de la rampe de led sur toutes les LED à ON
// -----------------------------------------------------------------------
void allLedset(int selstrip) {
  //--- the ring ---
  if (selstrip==1) {
    for(int i=0;i<NUMPIXELS;i++){
      if (led[i]==true) pixels.setPixelColor(i, userRingColor); else pixels.setPixelColor(i, ledOff);
      pixels.show(); // This sends the updated pixel color to the hardware.
    }
  }
  
  // --- the strip ---
  if (selstrip==2) {
    for(int i=0;i<NUMPIXELSSTRIP;i++){
      if (ledstrip[i]==true) pixelsstrip.setPixelColor(i, userStripColor); else pixelsstrip.setPixelColor(i, ledOff);
      pixelsstrip.show(); // This sends the updated pixel color to the hardware.
    }
  }  
}

// -------------------------------------------------------------------------------
// Effet no 2
// Parcours circulaire des leds à l'infini, avec N led allumées en même temps
// --------------------------------------------------------------------------------

// Defini le nombre de led allumée simultanément sur la boucle
void init_loopingEffect(int selstrip) {
  if (selstrip==1) {  
     for(int i=0;i<NUMPIXELS;i++){looptab[i]=false;} // valeur par defaut sur tous le tableau
     for(int i=0;i<NUMPIXELS/3;i++){looptab[i]=true;}
  }
  if (selstrip==2) {  
     for(int i=0;i<NUMPIXELSSTRIP;i++){looptabstrip[i]=false;} // valeur par defaut sur tous le tableau
     for(int i=0;i<NUMPIXELSSTRIP/3;i++){looptabstrip[i]=true;}
  }
     
}

void loopingEffect(int selstrip) {
  
  // Delay for a period of time (in milliseconds).
  currentMillis =  millis();
  
  if (int(currentMillis - previousMillis) >= speedEffect) {
    if (selstrip==1) {  
      for(int i=0;i<NUMPIXELS;i++){
        if (led[i]==true && looptab[i]==true) pixels.setPixelColor(i, userRingColor); else pixels.setPixelColor(i, ledOff);
      }  
      pixels.show(); // This sends the updated pixel color to the hardware.
        
       // Décalage de 1 vers la droite du tableau en circulaire
       boolean lastvalue=looptab[NUMPIXELS-1];
       for(int i=NUMPIXELS-1;i>0;i--){
          looptab[i]=looptab[i-1];
       }  
       looptab[0]= lastvalue;
    }

    if (selstrip==2) {  
      for(int i=0;i<NUMPIXELSSTRIP;i++){
        if (ledstrip[i]==true && looptabstrip[i]==true) pixelsstrip.setPixelColor(i, userStripColor); else pixelsstrip.setPixelColor(i, ledOff);
      }  
      pixelsstrip.show(); // This sends the updated pixel color to the hardware.
        
       // Décalage de 1 vers la droite du tableau en circulaire
       boolean lastvalue=looptabstrip[NUMPIXELSSTRIP-1];
       for(int i=NUMPIXELSSTRIP-1;i>0;i--){
          looptabstrip[i]=looptabstrip[i-1];
       }  
       looptabstrip[0]= lastvalue;
    }

    // save the last time you blinked the LED
    previousMillis = currentMillis;

           
  }
}

// -----------------------------------------------------------------------
// Effet no 3
// Allume toutes les led à ON, puis les éteind en sens inverse etc...
// -----------------------------------------------------------------------
              
void resetLoopTab(int selstrip) {     
           
     // Eteint toutes les led avant de démarrer le nouvel effet
    if (selstrip==1) {       
     for(int i=0;i<NUMPIXELS;i++){looptab[i]=false;} // valeur par defaut sur tout le tableau
     dirEffectNo3=0;
    }

    if (selstrip==2) {       
     for(int i=0;i<NUMPIXELSSTRIP;i++){looptabstrip[i]=false;} // valeur par defaut sur tout le tableau
      dirEffectNo3=0;
    }         
}

void backAndForwardEffect(int selstrip) {
  int bf,i;
  // Delay for a period of time (in milliseconds).
  currentMillis =  millis();

  // L'evolution de l'effet se fait tous les X ms defini par la valeur de speedEffect.
  if (int(currentMillis - previousMillisBackAndForward) >= speedEffect) {


    // Allume les leds (0) ou les eteinds (1)  les unes après les autres.
    if (selstrip==1) {  
        // Allume les LED (une à la fois)
       // Serial.print("=> dIr = ");Serial.println(dirEffect);
       
       switch (dirEffectNo3) { 
        case 0:
          // allume une led de plus.
          for(bf=0;bf<NUMPIXELS;bf=bf+1){
            if (looptab[bf]==false) {
              looptab[bf]=true;
              // Serial.print("strip1-dir=0 picelnum=");Serial.println(bf);
              
              if (bf==(NUMPIXELS-1)) {debugMsg("changeDir");dirEffectNo3=1;}
              bf=NUMPIXELS;
              break;
            }
          }
          break;
          
       case 1:
       // Eteind les led les unes après les autres en sens inverse (1 à la fois)
          // éteind une led de plus.
          for(bf=NUMPIXELS-1;bf>=0;bf=bf-1){
            if (looptab[bf]==true) {
              looptab[bf]=false;
              //Serial.print("strip1-dir=1 picelnum=");Serial.println(bf);              
              
              if (bf==0) {dirEffectNo3=0;debugMsg("changeDir");}
              bf=-1;
              break;
            }
          }

       }
       
        // Affiche l'état du tableau de led
        for(i=0;i<NUMPIXELS;i++){
          if (led[i]==true && looptab[i]==true) pixels.setPixelColor(i, userRingColor); else pixels.setPixelColor(i, ledOff);
        }  
        pixels.show(); 
    }

     // A revoir duplication de code Quick & dirty
     if (selstrip==2) {  
        // Allume les LED (une à la fois)
        if (dirEffect==0) {
          // allume une led de plus.
          for(i=0;i<NUMPIXELSSTRIP;i++){
            if (looptabstrip[i]==false) {
              looptabstrip[i]=true;
              break;
            }
          }
          if (i==NUMPIXELSSTRIP) dirEffect=1;
        }
    
       // Eteind les led les unes après les autres en sens inverse (1 à la fois)
        if (dirEffect==1) {
          // éteind une led de plus.
          for(i=NUMPIXELSSTRIP-1;i>=0;i--){
            if (looptabstrip[i]==true) {
              looptabstrip[i]=false;
              break;
            }
          }
          if (i==0) dirEffect=0;
        }
    
        // Affiche l'état du tableau de led
        for(i=0;i<NUMPIXELSSTRIP;i++){
          if (ledstrip[i]==true && looptabstrip[i]==true) pixelsstrip.setPixelColor(i, userStripColor); else pixelsstrip.setPixelColor(i, ledOff);
        }  
        pixelsstrip.show(); 
    }

    // sauvegarde la dernière fois ou une modificaiton à été faite
    previousMillisBackAndForward = currentMillis;  
       
  }
}


// -----------------------------------------------------------------------
// Effet no 4
// Augmente et diminue l'intensité des leds 
// -----------------------------------------------------------------------
void blowingEffect(int selstrip) {

  // Delay for a period of time (in milliseconds).
  currentMillis =  millis();
  
  if (int(currentMillis - previousMillisBlowEffect) >= speedEffect) {
    // save the last time you blinked the LED
    previousMillisBlowEffect = currentMillis;
      
    if (brightness<10) dirBrightness=+1;
    if (brightness>230) dirBrightness=-1;
    brightness=brightness+dirBrightness*10;

    if (selstrip==1) {
      pixels.setBrightness(brightness); // a remplacer car ne pas utiliser en boucle mais une seule fois dans le setup
      
      for(int i=0;i<NUMPIXELS;i++){
        if (led[i]==true) pixels.setPixelColor(i, userRingColor); else pixels.setPixelColor(i, ledOff);
        pixels.show(); // This sends the updated pixel color to the hardware.
      }
      pixels.show();
     }   


    if (selstrip==2) {
      pixelsstrip.setBrightness(brightness); // a remplacer car ne pas utiliser en boucle mais une seule fois dans le setup
      
      for(int i=0;i<NUMPIXELSSTRIP;i++){
        if (ledstrip[i]==true) pixelsstrip.setPixelColor(i, userStripColor); else pixelsstrip.setPixelColor(i, ledOff);
        pixelsstrip.show(); // This sends the updated pixel color to the hardware.
      }
      pixelsstrip.show();
     }  

      
  } 
}

// -------------------------------------------
//  Eteind toutes les leds sur une rampe
// -------------------------------------------
void stopEffect(int selstrip) {
  if (selstrip==1) {
    for(int i=0;i<NUMPIXELS;i++){
      pixels.setPixelColor(i, pixels.Color(0,0,0));  // Eteint les leds
      pixels.show(); // This sends the updated pixel color to the hardware.
    } 
  }
  
  if (selstrip==2) {
    for(int i=0;i<NUMPIXELSSTRIP;i++){
      pixelsstrip.setPixelColor(i, pixelsstrip.Color(0,0,0));  // Eteint les leds
      pixelsstrip.show(); // This sends the updated pixel color to the hardware.
    } 
  }
}

// Affiche les messages en retour sur le port série
void debugMsg(String todisplay) {
  if (DEBUG==true)  Serial.println(todisplay);
}

// -----------------------------------------------------------
//  Display all the commande line instructions when HELP send
// -----------------------------------------------------------
void showInstructions() {
  Serial.println(F("Derniere mise a jour le : 13.03.2016 - v 1.10")); 
  Serial.println(F("Parametrage vitesse port serie : 38400 Bauds")); 
  Serial.println(F("Ring 12 led  NeoPixel Ring AdaFruit /  Strip 16 Led ")); 
  Serial.println(F(""));
  Serial.println(F("RING : Passe en mode configuration du Ring - Pin 10"));
  Serial.println(F("STRIP : Passe en mode configuration du strip de led - Pin 9"));
  Serial.println(F("RVB#DEFA12 : Change la couleur de toutes les led avec la valeure hexadecimal Rouge=#DE () / Vert=#FA () / Bleu = #12 ( )")); 
  Serial.println(F("RVB#DEFA12,1 : Change la couleur de La led no 1 (les leds sont numerotes de 0 à 11 ou 15")); 
  Serial.println(F("SPED500 : Speed a 500 ms permet de ralentir ou d'accelerer un effet lumineux")); 
  Serial.println(F("EFFE1 : Lance l'effet no 1 jusqu'a 4 a ce jour ")); 
  Serial.println(F("STOP  : Stop toute les annimations + eteint le ring")); 
  Serial.println(F("LEDT1 : Allume la led no 1 (Led true) impact toutes les animations")); 
  Serial.println(F("LEDF2 : Eteint la led no 2 (led False) impact sur toutes les animations")); 
  Serial.println(F("SAVE : Met en memoire EPROM les principaux parametres pour relancer l'animation parametree au demarage de l'Arduino")); 
  Serial.println(F("LOAD : Recharge les parametres de l'effet sauvegarde en memoire"));
  Serial.println(F("DEBUGON : envoie en serie les messages de gestion des traitements et erreurs")); 
  Serial.println(F("DEBUGOFF : n'envoie aucun message d'erreur, comportement par defaut"));   
}

